/*
 * ObjectData.java
 * Created on 2011/10/13
 *
 * Copyright (C) 2011-2013 Nippon Telegraph and Telephone Corporation
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 */

package jp.co.ntt.oss.heapstats.container;

import java.io.Serializable;

/**
 * implements {@link Serializable}, {@link Cloneable} <br>
 * <br>
 * Contains information about the classes loaded in the java virtual machine.
 */
public class ObjectData implements
                       Serializable,
                       Cloneable {
    /** serialVersionUID. */
    private static final long serialVersionUID = -1685786847473848152L;

    /** Holds the tag to uniquely identify the class that is loaded. */
    private long tag;

    /** Class Name. */
    private String name;

    /** Holds the ID for uniquely identifying the ClassLoader. */
    private long classLoader;

    /** Holds the class tag that indicates the ClassLoader. */
    private long classLoaderTag;

    /** Instances of classes. */
    private long count;

    /** Total heap usage class. */
    private long totalSize;

    /** The name of the ClassLoader. */
    private String loaderName;

    /**
     * Create a ObjectData.
     */
    public ObjectData() {
        tag = 0;
        name = null;
        classLoader = -1;
        classLoaderTag = -1;
        count = 0;
        totalSize = 0;
    }

    /**
     * Sets the tag.
     *
     * @param value tag
     */
    public final void setTag(final long value) {
        tag = value;
    }

    /**
     * Return the tag.
     *
     * @return Return the tag
     */
    public final long getTag() {
        return tag;
    }

    /**
     * Sets the Class path.
     *
     * @param value Class path
     */
    public final void setName(final String value) {
        name = value;
    }

    /**
     * Return the Class Name.
     *
     * @return Return the Class Name
     */
    public final String getName() {
        return name;
    }

    /**
     * Return the class loader ID.
     *
     * @return Return the class loader ID
     */
    public final long getClassLoader() {
        return classLoader;
    }

    /**
     * Set the class loader ID.
     *
     * @param value class loader ID
     */
    public final void setClassLoader(final long value) {
        this.classLoader = value;
    }

    /**
     * Returns the unique tag of the class loader.
     *
     * @return Returns the unique tag of the class loader.
     */
    public final long getClassLoaderTag() {
        return classLoaderTag;
    }

    /**
     * Set the unique tag of the class loader.
     *
     * @param value unique tag
     */
    public final void setClassLoaderTag(final long value) {
        this.classLoaderTag = value;
    }

    /**
     * Sets the Object count.
     *
     * @param value Number of Classes
     */
    public final void setCount(final long value) {
        count = value;
    }

    /**
     * Return the Object count.
     *
     * @return Return the Object count
     */
    public final long getCount() {
        return count;
    }

    /**
     * Sets the total heap size.
     *
     * @param value total heap size
     */
    public final void setTotalSize(final long value) {
        totalSize = value;
    }

    /**
     * Return the total heap size.
     *
     * @return Return the total heap size
     */
    public final long getTotalSize() {
        return totalSize;
    }

    /**
     * Returns the name of the class loader.
     *
     * @return Returns the name of the class loader
     */
    public final String getLoaderName() {
        return loaderName;
    }

    /**
     * Set the name of the class loader.
     *
     * @param value the name of the class loader.
     */
    public final void setLoaderName(final String value) {
        loaderName = value;
    }

    @Override
    public final String toString() {
        StringBuffer buf = new StringBuffer();

        buf.append(tag);
        buf.append(", ");
        buf.append(name);
        buf.append(", ");
        buf.append(classLoader);
        buf.append(", ");
        buf.append(classLoaderTag);
        buf.append(", ");
        buf.append(count);
        buf.append(", ");
        buf.append(totalSize);

        return buf.toString();
    }

    @Override
    public final ObjectData clone() {
        try {
            super.clone();
        } catch (CloneNotSupportedException e) {
            e.printStackTrace();
        }

        ObjectData cloneObj = new ObjectData();

        cloneObj.setTag(tag);
        cloneObj.setName(name);
        cloneObj.setClassLoader(classLoader);
        cloneObj.setClassLoaderTag(classLoaderTag);
        cloneObj.setCount(count);
        cloneObj.setTotalSize(totalSize);
        cloneObj.setLoaderName(loaderName);

        return cloneObj;
    }
}
